@@ -50,6 +50,10 @@ def wkhtmltopdf_bin(
             if chunk:
                 f.write(chunk)
 
+    if not gz_path.is_file():
+        print("==============================")
+        return
+
     with gzip.open(gz_path, "rb") as f_in:
         with open(bin_path, "wb") as f_out:
             shutil.copyfileobj(f_in, f_out)
